[PATCH v2 04/14] lmb: Rename memory/reserved_regions to area

Simon Glass sjg at chromium.org
Fri Sep 1 03:13:42 CEST 2023


Rename these two fields since they are areas, not regions.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

Changes in v2:
- Add new patch to rename memory/reserved_regions to area

 include/lmb.h | 8 ++++----
 lib/lmb.c     | 4 ++--
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/lib/lmb.c b/lib/lmb.c
index 9336792df8ba..2669868f0dda 100644
--- a/lib/lmb.c
+++ b/lib/lmb.c
@@ -113,8 +113,8 @@ void lmb_init(struct lmb *lmb)
 #else
 	lmb->memory.max = CONFIG_LMB_MEMORY_REGIONS;
 	lmb->reserved.max = CONFIG_LMB_RESERVED_REGIONS;
-	lmb->memory.region = lmb->memory_regions;
-	lmb->reserved.region = lmb->reserved_regions;
+	lmb->memory.area = lmb->memory_areas;
+	lmb->reserved.area = lmb->reserved_areas;
 #endif
 	lmb->memory.cnt = 0;
 	lmb->reserved.cnt = 0;
diff --git a/include/lmb.h b/include/lmb.h
index 9d4a05670c23..92332eb63069 100644
--- a/include/lmb.h
+++ b/include/lmb.h
@@ -80,15 +80,15 @@ struct lmb_region {
  *
  * @memory: Description of memory regions.
  * @reserved: Description of reserved regions.
  * @memory_regions: Array of the memory regions (statically allocated)
  * @reserved_regions: Array of the reserved regions (statically allocated)
  */
 struct lmb {
 	struct lmb_region memory;
 	struct lmb_region reserved;
 #if !IS_ENABLED(CONFIG_LMB_USE_MAX_REGIONS)
-	struct lmb_area memory_regions[CONFIG_LMB_MEMORY_REGIONS];
-	struct lmb_area reserved_regions[CONFIG_LMB_RESERVED_REGIONS];
+	struct lmb_area memory_areas[CONFIG_LMB_MEMORY_REGIONS];
+	struct lmb_area reserved_areas[CONFIG_LMB_RESERVED_REGIONS];
 #endif
 };
 
@@ -80,15 +80,15 @@ struct lmb_region {
  * @memory: Description of memory regions.
  * @reserved: Description of reserved regions.
- * @memory_regions: Array of the memory regions (statically allocated)
- * @reserved_regions: Array of the reserved regions (statically allocated)
+ * @memory_areas: Array of the memory areas (statically allocated)
+ * @reserved_areas: Array of the reserved areas (statically allocated)
  */
 struct lmb {
-- 
2.42.0.283.g2d96d420d3-goog



More information about the U-Boot mailing list